﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;


namespace StressTest
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			lineChart.LineType = LineType.Curve;
			
			// set MinValue and MaxValue of axes explicitly, or otherwise
			// the chart will loop over all data to set them automatically
			lineChart.XAxis.MinValue = 0;
			lineChart.XAxis.MaxValue = 200;
			lineChart.XAxis.Title = "X Axis";
			lineChart.YAxis.MinValue = -50;
			lineChart.YAxis.MaxValue = 150;
			lineChart.YAxis.Title = "Y Axis";

			// Generator.IsSorted returns true for X axis, so the chart uses O(log(n)) search algorithms
			lineChart.Series.Add(new Generator(500000, 1000000, 100) { Title = "Generated series 1"});
			lineChart.Series.Add(new Generator(250000, 20000, 50) { Title = "Generated series 2" });

			// customize appearance
			lineChart.ShowLegend = true;
			lineChart.ShowLegendTitle = false;
			lineChart.LegendHorizontalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;
			lineChart.LegendVerticalAlignment = MindFusion.Charting.Components.LayoutAlignment.Near;
			lineChart.Theme.LegendBackground = new MindFusion.Drawing.SolidBrush(Color.Transparent);
			/* opaque legend background makes the chart slower 
			lineChart.Theme.LegendBackground = new MindFusion.Drawing.SolidBrush(Color.White); */

			/* grid rendering makes the chart slower
			lineChart.Theme.GridColor1 = Color.White;
			lineChart.Theme.GridColor2 = Color.FromArgb(245, 245, 245);
			lineChart.GridType = GridType.Horizontal; */
			lineChart.Theme.CommonSeriesStrokes = lineChart.Theme.CommonSeriesFills =
				new List<MindFusion.Drawing.Brush>
          		{
          			new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
          		};
			/* thicker lines slow down chart rendering 
			lineChart.Theme.CommonSeriesStrokeThicknesses = new List<double>() { 4.0 }; */
		}
	}
}